| medications | R Documentation |
A data frame with example medications that might be used during fertility treatment/first trimester.
It is an example of a data frame that might be used as the meds argument to medications_remaining().
medications
medications_simple
medications is a data frame with 14 rows and 5 columns.
medications_simple is a data frame with 4 rows and 5 columns.
Name of the medication
Format of medication
Number taken per day
Date to start taking the medication
Final date on which the medication is taken. See details.
An object of class tbl_df (inherits from tbl, data.frame) with 4 rows and 5 columns.
Note that the same medication (prednisolone in this example) has several rows, first because the quantity taken per day changes, then because it needs to be taken on non-consecutive days.
medications_remaining()
medications
medications_simple
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.