Learn R Programming

pregnancy (version 0.2.1)

medications: An example medications table

Description

A data frame with example medications that might be used during fertility treatment/first trimester. It is an example of a data frame that might be used as the meds argument to medications_remaining().

Usage

medications

medications_simple

Arguments

Format

medications is a data frame with 14 rows and 5 columns. medications_simple is a data frame with 4 rows and 5 columns.

medication

Name of the medication

format

Format of medication

quantity

Number taken per day

start_date

Date to start taking the medication

stop_date

Final date on which the medication is taken. See details.

An object of class tbl_df (inherits from tbl, data.frame) with 4 rows and 5 columns.

Details

Note that the same medication (prednisolone in this example) has several rows, first because the quantity taken per day changes, then because it needs to be taken on non-consecutive days.

See Also

medications_remaining()

Examples

Run this code
medications
medications_simple

Run the code above in your browser using DataLab